@@ -62,7 +62,6 @@ struct GsdA11yKeyboardManagerPrivate
         GtkWidget        *slowkeys_alert;
         GtkWidget        *preferences_dialog;
         GtkStatusIcon    *status_icon;
-        XkbDescRec       *original_xkb_desc;
 
         GSettings        *settings;
 
@@ -894,8 +893,17 @@ cb_xkb_event_filter (GdkXEvent              *xevent,
         XEvent   *xev   = (XEvent *) xevent;
         XkbEvent *xkbEv = (XkbEvent *) xevent;
 
+        /* 'event_type' is set to zero on notifying us of updates in
+         * response to client requests (including our own) and non-zero
+         * to notify us of key/mouse events causing changes (like
+         * pressing shift 5 times to enable sticky keys).
+         *
+         * We only want to update GSettings when it's in response to an
+         * explicit user input event, so require a non-zero event_type.
+         */
         if (xev->xany.type == (manager->priv->xkbEventBase + XkbEventCode) &&
-            xkbEv->any.xkb_type == XkbControlsNotify) {
+            xkbEv->any.xkb_type == XkbControlsNotify &&
+            xkbEv->ctrls.event_type != 0) {
                 g_debug ("XKB state changed");
                 set_gsettings_from_server (manager);
         } else if (xev->xany.type == (manager->priv->xkbEventBase + XkbEventCode) &&
@@ -939,10 +947,6 @@ start_a11y_keyboard_idle_cb (GsdA11yKeyboardManager *manager)
 
         set_devicepresence_handler (manager);
 
-        /* Save current xkb state so we can restore it on exit
-         */
-        manager->priv->original_xkb_desc = get_xkb_desc_rec (manager);
-
         event_mask = XkbControlsNotifyMask;
         event_mask |= XkbAccessXNotifyMask; /* make default when AXN_AXKWarning works */
 
@@ -981,34 +985,6 @@ gsd_a11y_keyboard_manager_start (GsdA11yKeyboardManager *manager,
         return TRUE;
 }
 
-static void
-restore_server_xkb_config (GsdA11yKeyboardManager *manager)
-{
-        if (manager->priv->original_xkb_desc == NULL) {
-                return;
-        }
-        gdk_error_trap_push ();
-        XkbSetControls (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
-                        XkbSlowKeysMask         |
-                        XkbBounceKeysMask       |
-                        XkbStickyKeysMask       |
-                        XkbMouseKeysMask        |
-                        XkbMouseKeysAccelMask   |
-                        XkbAccessXKeysMask      |
-                        XkbAccessXTimeoutMask   |
-                        XkbAccessXFeedbackMask  |
-                        XkbControlsEnabledMask,
-                        manager->priv->original_xkb_desc);
-
-        XkbFreeKeyboard (manager->priv->original_xkb_desc,
-                         XkbAllComponentsMask, True);
-
-        XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-        gdk_error_trap_pop_ignored ();
-
-        manager->priv->original_xkb_desc = NULL;
-}
-
 void
 gsd_a11y_keyboard_manager_stop (GsdA11yKeyboardManager *manager)
 {
@@ -1041,10 +1017,6 @@ gsd_a11y_keyboard_manager_stop (GsdA11yKeyboardManager *manager)
                                   (GdkFilterFunc) cb_xkb_event_filter,
                                   manager);
 
-        /* Disable all the AccessX bits
-         */
-        restore_server_xkb_config (manager);
-
         if (p->slowkeys_alert != NULL) {
                 gtk_widget_destroy (p->slowkeys_alert);
                 p->slowkeys_alert = NULL;
